# How to cite SHRY

(citation_of_SHRY)=

## Citation of SHRY

If you used SHRY in your reseach project, please cite the following articles.
This indeed helps the SHRY project to continue:

- [SHRY: Application of Canonical Augmentation to the Atomic Substitution Problem](https://doi.org/10.1021/acs.jcim.2c00389),
  G.I. Prayogo*, A. Tirelli, K. Utimula, K. Hongo, R. Maezono, and K. Nakano*,
  *J. Chem. Inf. Model.*, 62, 2909-2915 (2022),
  DOI: [10.1021/acs.jcim.2c00389](https://doi.org/10.1021/acs.jcim.2c00389)

  ```
  @article{prayogo2022shry,
    author  = {Prayogo, Genki I. and Tirelli, Andrea and Utimula, Keisuke and Hongo, Kenta and Maezono, Ryo and Nakano, Kosuke},
    title   = {SHRY: Application of Canonical Augmentation to the Atomic Substitution Problem},
    journal = {Journal of Chemical Information and Modeling},
    volume  = {62},
    number  = {12},
    pages   = {2909-2915},
    year    = {2022},
    doi     = {10.1021/acs.jcim.2c00389}
  }
  ```
